@@ -12,7 +12,7 @@ from dagster.core.definitions import (
     ExpectationResult,
     HookDefinition,
     Materialization,
-    SolidHandle,
+    NodeHandle,
 )
 from dagster.core.definitions.events import AssetLineageInfo, ObjectStoreOperationType
 from dagster.core.errors import DagsterError, HookExecutionError
@@ -27,6 +27,7 @@ from dagster.core.execution.context.system import (
 from dagster.core.execution.plan.handle import ResolvedFromDynamicStepHandle, StepHandle
 from dagster.core.execution.plan.outputs import StepOutputData
 from dagster.core.log_manager import DagsterLogManager
+from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.serdes import register_serdes_tuple_fallbacks, whitelist_for_serdes
 from dagster.utils.error import SerializableErrorInfo, serializable_error_info_from_exc_info
 from dagster.utils.timing import format_duration
@@ -77,16 +78,29 @@ class DagsterEventType(Enum):
     ASSET_MATERIALIZATION = "ASSET_MATERIALIZATION"
     STEP_EXPECTATION_RESULT = "STEP_EXPECTATION_RESULT"
 
-    PIPELINE_ENQUEUED = "PIPELINE_ENQUEUED"
-    PIPELINE_DEQUEUED = "PIPELINE_DEQUEUED"
-    PIPELINE_STARTING = "PIPELINE_STARTING"  # Launch is happening, execution hasn't started yet
+    # We want to display RUN_* events in dagit and in our LogManager output, but in order to
+    # support backcompat for our storage layer, we need to keep the persisted value to be strings
+    # of the form "PIPELINE_*".  We may have user code that pass in the DagsterEventType
+    # enum values into storage APIs (like get_event_records, which takes in an EventRecordsFilter).
+    RUN_ENQUEUED = "PIPELINE_ENQUEUED"
+    RUN_DEQUEUED = "PIPELINE_DEQUEUED"
+    RUN_STARTING = "PIPELINE_STARTING"  # Launch is happening, execution hasn't started yet
+    RUN_START = "PIPELINE_START"  # Execution has started
+    RUN_SUCCESS = "PIPELINE_SUCCESS"
+    RUN_FAILURE = "PIPELINE_FAILURE"
+    RUN_CANCELING = "PIPELINE_CANCELING"
+    RUN_CANCELED = "PIPELINE_CANCELED"
 
-    PIPELINE_START = "PIPELINE_START"  # Execution has started
-    PIPELINE_SUCCESS = "PIPELINE_SUCCESS"
-    PIPELINE_FAILURE = "PIPELINE_FAILURE"
-
-    PIPELINE_CANCELING = "PIPELINE_CANCELING"
-    PIPELINE_CANCELED = "PIPELINE_CANCELED"
+    # Keep these legacy enum values around, to keep back-compatability for user code that might be
+    # using these constants to filter event records
+    PIPELINE_ENQUEUED = RUN_ENQUEUED
+    PIPELINE_DEQUEUED = RUN_DEQUEUED
+    PIPELINE_STARTING = RUN_STARTING
+    PIPELINE_START = RUN_START
+    PIPELINE_SUCCESS = RUN_SUCCESS
+    PIPELINE_FAILURE = RUN_FAILURE
+    PIPELINE_CANCELING = RUN_CANCELING
+    PIPELINE_CANCELED = RUN_CANCELED
 
     OBJECT_STORE_OPERATION = "OBJECT_STORE_OPERATION"
     ASSET_STORE_OPERATION = "ASSET_STORE_OPERATION"
@@ -104,6 +118,17 @@ class DagsterEventType(Enum):
     LOGS_CAPTURED = "LOGS_CAPTURED"
 
 
+EVENT_TYPE_VALUE_TO_DISPLAY_STRING = {
+    "PIPELINE_ENQUEUED": "RUN_ENQUEUED",
+    "PIPELINE_DEQUEUED": "RUN_DEQUEUED",
+    "PIPELINE_STARTING": "RUN_STARTING",
+    "PIPELINE_START": "RUN_START",
+    "PIPELINE_SUCCESS": "RUN_SUCCESS",
+    "PIPELINE_FAILURE": "RUN_FAILURE",
+    "PIPELINE_CANCELING": "RUN_CANCELING",
+    "PIPELINE_CANCELED": "RUN_CANCELED",
+}
+
 STEP_EVENTS = {
     DagsterEventType.STEP_INPUT,
     DagsterEventType.STEP_START,
@@ -121,20 +146,20 @@ STEP_EVENTS = {
 }
 
 FAILURE_EVENTS = {
-    DagsterEventType.PIPELINE_FAILURE,
+    DagsterEventType.RUN_FAILURE,
     DagsterEventType.STEP_FAILURE,
-    DagsterEventType.PIPELINE_CANCELED,
+    DagsterEventType.RUN_CANCELED,
 }
 
 PIPELINE_EVENTS = {
-    DagsterEventType.PIPELINE_ENQUEUED,
-    DagsterEventType.PIPELINE_DEQUEUED,
-    DagsterEventType.PIPELINE_STARTING,
-    DagsterEventType.PIPELINE_START,
-    DagsterEventType.PIPELINE_SUCCESS,
-    DagsterEventType.PIPELINE_FAILURE,
-    DagsterEventType.PIPELINE_CANCELING,
-    DagsterEventType.PIPELINE_CANCELED,
+    DagsterEventType.RUN_ENQUEUED,
+    DagsterEventType.RUN_DEQUEUED,
+    DagsterEventType.RUN_STARTING,
+    DagsterEventType.RUN_START,
+    DagsterEventType.RUN_SUCCESS,
+    DagsterEventType.RUN_FAILURE,
+    DagsterEventType.RUN_CANCELING,
+    DagsterEventType.RUN_CANCELED,
 }
 
 HOOK_EVENTS = {
@@ -149,6 +174,19 @@ ALERT_EVENTS = {
 }
 
 
+EVENT_TYPE_TO_PIPELINE_RUN_STATUS = {
+    DagsterEventType.RUN_START: PipelineRunStatus.STARTED,
+    DagsterEventType.RUN_SUCCESS: PipelineRunStatus.SUCCESS,
+    DagsterEventType.RUN_FAILURE: PipelineRunStatus.FAILURE,
+    DagsterEventType.RUN_ENQUEUED: PipelineRunStatus.QUEUED,
+    DagsterEventType.RUN_STARTING: PipelineRunStatus.STARTING,
+    DagsterEventType.RUN_CANCELING: PipelineRunStatus.CANCELING,
+    DagsterEventType.RUN_CANCELED: PipelineRunStatus.CANCELED,
+}
+
+PIPELINE_RUN_STATUS_TO_EVENT_TYPE = {v: k for k, v in EVENT_TYPE_TO_PIPELINE_RUN_STATUS.items()}
+
+
 def _assert_type(
     method: str, expected_type: DagsterEventType, actual_type: DagsterEventType
 ) -> None:
@@ -187,47 +225,32 @@ def _validate_event_specific_data(
 
 
 def log_step_event(step_context: IStepContext, event: "DagsterEvent") -> None:
-
     event_type = DagsterEventType(event.event_type_value)
-    log_fn = step_context.log.error if event_type in FAILURE_EVENTS else step_context.log.debug
+    log_level = logging.ERROR if event_type in FAILURE_EVENTS else logging.DEBUG
 
-    log_fn(
-        event.message
-        or "{event_type} for step {step_key}".format(
-            event_type=event_type, step_key=step_context.step.key
-        ),
+    step_context.log.log_dagster_event(
+        level=log_level,
+        msg=event.message or f"{event_type} for step {step_context.step.key}",
         dagster_event=event,
-        pipeline_name=step_context.pipeline_name,
     )
 
 
-def log_pipeline_event(
-    pipeline_context: IPlanContext, event: "DagsterEvent", step_key: Optional[str]
-) -> None:
+def log_pipeline_event(pipeline_context: IPlanContext, event: "DagsterEvent") -> None:
     event_type = DagsterEventType(event.event_type_value)
+    log_level = logging.ERROR if event_type in FAILURE_EVENTS else logging.DEBUG
 
-    log_fn = (
-        pipeline_context.log.error if event_type in FAILURE_EVENTS else pipeline_context.log.debug
-    )
-
-    log_fn(
-        event.message
-        or "{event_type} for pipeline {pipeline_name}".format(
-            event_type=event_type, pipeline_name=pipeline_context.pipeline_name
-        ),
+    pipeline_context.log.log_dagster_event(
+        level=log_level,
+        msg=event.message or f"{event_type} for pipeline {pipeline_context.pipeline_name}",
         dagster_event=event,
-        pipeline_name=pipeline_context.pipeline_name,
-        step_key=step_key,
     )
 
 
-def log_resource_event(
-    log_manager: DagsterLogManager, pipeline_name: str, event: "DagsterEvent"
-) -> None:
+def log_resource_event(log_manager: DagsterLogManager, event: "DagsterEvent") -> None:
     event_specific_data = cast(EngineEventData, event.event_specific_data)
 
-    log_fn = log_manager.error if event_specific_data.error else log_manager.debug
-    log_fn(event.message, dagster_event=event, pipeline_name=pipeline_name, step_key=event.step_key)
+    log_level = logging.ERROR if event_specific_data.error else logging.DEBUG
+    log_manager.log_dagster_event(level=log_level, msg=event.message or "", dagster_event=event)
 
 
 @whitelist_for_serdes
@@ -238,7 +261,7 @@ class DagsterEvent(
             ("event_type_value", str),
             ("pipeline_name", str),
             ("step_handle", Optional[Union[StepHandle, ResolvedFromDynamicStepHandle]]),
-            ("solid_handle", Optional[SolidHandle]),
+            ("solid_handle", Optional[NodeHandle]),
             ("step_kind_value", Optional[str]),
             ("logging_tags", Optional[Dict[str, str]]),
             ("event_specific_data", Optional["EventSpecificData"]),
@@ -255,8 +278,7 @@ class DagsterEvent(
     Attributes:
         event_type_value (str): Value for a DagsterEventType.
         pipeline_name (str)
-        step_key (str)
-        solid_handle (SolidHandle)
+        solid_handle (NodeHandle)
         step_kind_value (str): Value for a StepKind.
         logging_tags (Dict[str, str])
         event_specific_data (Any): Type must correspond to event_type_value.
@@ -309,8 +331,8 @@ class DagsterEvent(
             step_handle=step_handle,
             pid=os.getpid(),
         )
-        step_key = step_handle.to_key() if step_handle else None
-        log_pipeline_event(pipeline_context, event, step_key)
+
+        log_pipeline_event(pipeline_context, event)
 
         return event
 
@@ -333,7 +355,7 @@ class DagsterEvent(
             step_handle=execution_plan.step_handle_for_single_step_plans(),
             pid=os.getpid(),
         )
-        log_resource_event(log_manager, pipeline_name, event)
+        log_resource_event(log_manager, event)
         return event
 
     def __new__(
@@ -341,7 +363,7 @@ class DagsterEvent(
         event_type_value: str,
         pipeline_name: str,
         step_handle: Optional[Union[StepHandle, ResolvedFromDynamicStepHandle]] = None,
-        solid_handle: Optional[SolidHandle] = None,
+        solid_handle: Optional[NodeHandle] = None,
         step_kind_value: Optional[str] = None,
         logging_tags: Optional[Dict[str, str]] = None,
         event_specific_data: Optional["EventSpecificData"] = None,
@@ -370,7 +392,7 @@ class DagsterEvent(
             check.opt_inst_param(
                 step_handle, "step_handle", (StepHandle, ResolvedFromDynamicStepHandle)
             ),
-            check.opt_inst_param(solid_handle, "solid_handle", SolidHandle),
+            check.opt_inst_param(solid_handle, "solid_handle", NodeHandle),
             check.opt_str_param(step_kind_value, "step_kind_value"),
             check.opt_dict_param(logging_tags, "logging_tags"),
             _validate_event_specific_data(DagsterEventType(event_type_value), event_specific_data),
@@ -382,7 +404,7 @@ class DagsterEvent(
     @property
     def solid_name(self) -> str:
         check.invariant(self.solid_handle is not None)
-        solid_handle = cast(SolidHandle, self.solid_handle)
+        solid_handle = cast(NodeHandle, self.solid_handle)
         return solid_handle.name
 
     @property
@@ -438,11 +460,11 @@ class DagsterEvent(
 
     @property
     def is_pipeline_success(self) -> bool:
-        return self.event_type == DagsterEventType.PIPELINE_SUCCESS
+        return self.event_type == DagsterEventType.RUN_SUCCESS
 
     @property
     def is_pipeline_failure(self) -> bool:
-        return self.event_type == DagsterEventType.PIPELINE_FAILURE
+        return self.event_type == DagsterEventType.RUN_FAILURE
 
     @property
     def is_failure(self) -> bool:
@@ -531,7 +553,7 @@ class DagsterEvent(
 
     @property
     def pipeline_failure_data(self) -> "PipelineFailureData":
-        _assert_type("pipeline_failure_data", DagsterEventType.PIPELINE_FAILURE, self.event_type)
+        _assert_type("pipeline_failure_data", DagsterEventType.RUN_FAILURE, self.event_type)
         return cast(PipelineFailureData, self.event_specific_data)
 
     @property
@@ -725,9 +747,9 @@ class DagsterEvent(
     @staticmethod
     def pipeline_start(pipeline_context: IPlanContext) -> "DagsterEvent":
         return DagsterEvent.from_pipeline(
-            DagsterEventType.PIPELINE_START,
+            DagsterEventType.RUN_START,
             pipeline_context,
-            message='Started execution of pipeline "{pipeline_name}".'.format(
+            message='Started execution of run for "{pipeline_name}".'.format(
                 pipeline_name=pipeline_context.pipeline_name
             ),
         )
@@ -735,9 +757,9 @@ class DagsterEvent(
     @staticmethod
     def pipeline_success(pipeline_context: IPlanContext) -> "DagsterEvent":
         return DagsterEvent.from_pipeline(
-            DagsterEventType.PIPELINE_SUCCESS,
+            DagsterEventType.RUN_SUCCESS,
             pipeline_context,
-            message='Finished execution of pipeline "{pipeline_name}".'.format(
+            message='Finished execution of run for "{pipeline_name}".'.format(
                 pipeline_name=pipeline_context.pipeline_name
             ),
         )
@@ -751,9 +773,9 @@ class DagsterEvent(
         check.str_param(context_msg, "context_msg")
         if isinstance(pipeline_context_or_name, IPlanContext):
             return DagsterEvent.from_pipeline(
-                DagsterEventType.PIPELINE_FAILURE,
+                DagsterEventType.RUN_FAILURE,
                 pipeline_context_or_name,
-                message='Execution of pipeline "{pipeline_name}" failed. {context_msg}'.format(
+                message='Execution of run for "{pipeline_name}" failed. {context_msg}'.format(
                     pipeline_name=pipeline_context_or_name.pipeline_name,
                     context_msg=context_msg,
                 ),
@@ -764,10 +786,10 @@ class DagsterEvent(
             # built and so can't use from_pipeline
             check.str_param(pipeline_context_or_name, "pipeline_name")
             event = DagsterEvent(
-                event_type_value=DagsterEventType.PIPELINE_FAILURE.value,
+                event_type_value=DagsterEventType.RUN_FAILURE.value,
                 pipeline_name=pipeline_context_or_name,
                 event_specific_data=PipelineFailureData(error_info),
-                message='Execution of pipeline "{pipeline_name}" failed. {context_msg}'.format(
+                message='Execution of run for "{pipeline_name}" failed. {context_msg}'.format(
                     pipeline_name=pipeline_context_or_name,
                     context_msg=context_msg,
                 ),
@@ -780,9 +802,9 @@ class DagsterEvent(
         pipeline_context: IPlanContext, error_info: Optional[SerializableErrorInfo] = None
     ) -> "DagsterEvent":
         return DagsterEvent.from_pipeline(
-            DagsterEventType.PIPELINE_CANCELED,
+            DagsterEventType.RUN_CANCELED,
             pipeline_context,
-            message='Execution of pipeline "{pipeline_name}" canceled.'.format(
+            message='Execution of run for "{pipeline_name}" canceled.'.format(
                 pipeline_name=pipeline_context.pipeline_name
             ),
             event_specific_data=PipelineCanceledData(
@@ -1035,14 +1057,12 @@ class DagsterEvent(
             step_kind_value=step_context.step.kind.value,
             logging_tags=step_context.logging_tags,
             message=(
-                'Finished the execution of hook "{hook_name}" triggered for solid "{solid_name}".'
+                'Finished the execution of hook "{hook_name}" triggered for "{solid_name}".'
             ).format(hook_name=hook_def.name, solid_name=step_context.solid.name),
         )
 
-        step_context.log.debug(
-            event.message,
-            dagster_event=event,
-            pipeline_name=step_context.pipeline_name,
+        step_context.log.log_dagster_event(
+            level=logging.DEBUG, msg=event.message or "", dagster_event=event
         )
 
         return event
@@ -1068,11 +1088,7 @@ class DagsterEvent(
             ),
         )
 
-        step_context.log.error(
-            str(error),
-            dagster_event=event,
-            pipeline_name=step_context.pipeline_name,
-        )
+        step_context.log.log_dagster_event(level=logging.ERROR, msg=str(error), dagster_event=event)
 
         return event
 
@@ -1091,14 +1107,12 @@ class DagsterEvent(
             logging_tags=step_context.logging_tags,
             message=(
                 'Skipped the execution of hook "{hook_name}". It did not meet its triggering '
-                'condition during the execution of solid "{solid_name}".'
+                'condition during the execution of "{solid_name}".'
             ).format(hook_name=hook_def.name, solid_name=step_context.solid.name),
         )
 
-        step_context.log.debug(
-            event.message,
-            dagster_event=event,
-            pipeline_name=step_context.pipeline_name,
+        step_context.log.log_dagster_event(
+            level=logging.DEBUG, msg=event.message or "", dagster_event=event
         )
 
         return event
@@ -1198,7 +1212,7 @@ class ObjectStoreOperationResultData(
     NamedTuple(
         "_ObjectStoreOperationResultData",
         [
-            ("op", str),
+            ("op", ObjectStoreOperationType),
             ("value_name", Optional[str]),
             ("metadata_entries", List[EventMetadataEntry]),
             ("address", Optional[str]),
@@ -1209,7 +1223,7 @@ class ObjectStoreOperationResultData(
 ):
     def __new__(
         cls,
-        op: str,
+        op: ObjectStoreOperationType,
         value_name: Optional[str] = None,
         metadata_entries: Optional[List[EventMetadataEntry]] = None,
         address: Optional[str] = None,
@@ -1218,7 +1232,7 @@ class ObjectStoreOperationResultData(
     ):
         return super(ObjectStoreOperationResultData, cls).__new__(
             cls,
-            op=check.str_param(op, "op"),
+            op=cast(ObjectStoreOperationType, check.str_param(op, "op")),
             value_name=check.opt_str_param(value_name, "value_name"),
             metadata_entries=check.opt_list_param(
                 metadata_entries, "metadata_entries", of_type=EventMetadataEntry
